==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/pl.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Twoje ustawienia zostały zaktualizowane",
"Activity" => "Aktywność",
"A file or folder has been <strong>shared</strong>" => "Plik lub folder stał się <strong>współdzielony</strong>",
"A new file or folder has been <strong>created</strong> in a shared folder" => "<strong>Utworzono</strong> nowy plik lub folder wewnątrz współdzielonego folderu",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Plik lub folder wewnątrz współdzielonego folderu został <strong>zmieniony</strong>",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Plik lub folder wewnątrz współdzielonego folderu został <strong>usunięty</strong>",
"You created %1\$s" => "Utworzyłeś %1\$s",
"%2\$s created %1\$s" => "%2\$s utworzył %1\$s",
"You changed %1\$s" => "Zmieniłeś %1\$s",
"%2\$s changed %1\$s" => "%2\$s zmienił %1\$s",
"You deleted %1\$s" => "Usunąłeś %1\$s",
"%2\$s deleted %1\$s" => "%2\$s usunął %1\$s",
"You shared %1\$s with %2\$s" => "Współdzielisz %1\$s z %2\$s",
"You shared %1\$s with group %2\$s" => "Współdzielisz %1\$s z grupą %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s współdzieli %1\$s z Tobą",
"You shared %1\$s via link" => "Udostępniasz %1\$s publicznie",
"Activity notification" => "Powiadomienie o aktywniości",
"All Activities" => "Wszystkie aktywności",
"Activities by you" => "Twoje aktywności",
"Activities by others" => "Aktywności innych",
"Shares" => "Udziały",
"Files" => "Pliki",
"%s and %s" => "%s oraz %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s i <strong class=\"tooltip\" title=\"%s\">%n więcej</strong>","%s i <strong class=\"tooltip\" title=\"%s\">%n więcej</strong>","%s i <strong class=\"tooltip\" title=\"%s\">%n więcej</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s i %n więcej","%s i %n więcej","%s i %n więcej"),
"Hello %s," => "Witaj %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Otrzymujesz ten email, ponieważ w ostatniej godzinie zdarzyły się następujące rzeczy w %s",
"You are receiving this email because in the last day the following things happened at %s" => "Otrzymujesz ten email, ponieważ ostatniego dnia zdarzyły się następujące rzeczy w %s",
"You are receiving this email because in the last week the following things happened at %s" => "Otrzymujesz ten email, ponieważ w ostatnim tygodniu zdarzyły się następujące rzeczy w %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Zobaczysz listę wydarzeń tutaj, podczas rozpoczęcia korzystania z twojego %s",
"No more events to load" => "Nie pozostały już żadne zdarzenia do załadowania",
"Enable RSS feed" => "Włącz strumień RSS",
"Notifications" => "Powiadomienia",
"Mail" => "Poczta",
"Stream" => "Strumień",
"You need to set up your email address before you can receive notification emails." => "Musisz najpierw ustawić adres email zanim będziesz mógł otrzymywać powiadomienia.",
"Send emails:" => "Wyślij maile:",
"Hourly" => "Co godzinę",
"Daily" => "Codziennie",
"Weekly" => "Cotygodniowo",
"Activity feed" => "Strumień aktywności",
"Personal activity feed for %s" => "Osobisty strumień aktywności dla %s"
);
$PLURAL_FORMS = "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/pl.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Twoje ustawienia zostały zaktualizowane",
"Activity" => "Aktywność",
"A file or folder has been <strong>shared</strong>" => "Plik lub folder stał się <strong>współdzielony</strong>",
"A new file or folder has been <strong>created</strong>" => "Nowy plik lub folder został <strong>stworzony</strong>",
"A file or folder has been <strong>changed</strong>" => "Plik lub folder został <strong>zmieniony</strong>",
"A file or folder has been <strong>deleted</strong>" => "Plik lub folder został <strong>usunięty</strong>",
"You created %1\$s" => "Utworzyłeś %1\$s",
"%2\$s created %1\$s" => "%2\$s utworzył %1\$s",
"You changed %1\$s" => "Zmieniłeś %1\$s",
"%2\$s changed %1\$s" => "%2\$s zmienił %1\$s",
"You deleted %1\$s" => "Usunąłeś %1\$s",
"%2\$s deleted %1\$s" => "%2\$s usunął %1\$s",
"You shared %1\$s with %2\$s" => "Współdzielisz %1\$s z %2\$s",
"You shared %1\$s with group %2\$s" => "Współdzielisz %1\$s z grupą %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s współdzieli %1\$s z Tobą",
"You shared %1\$s via link" => "Udostępniasz %1\$s publicznie",
"Activity notification" => "Powiadomienie o aktywności",
"All Activities" => "Wszystkie aktywności",
"Activities by you" => "Twoje aktywności",
"Activities by others" => "Aktywności innych",
"Shares" => "Udziały",
"Files" => "Pliki",
"%s and %s" => "%s oraz %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s i <strong class=\"tooltip\" title=\"%s\">%n więcej</strong>","%s i <strong class=\"tooltip\" title=\"%s\">%n więcej</strong>","%s i <strong class=\"tooltip\" title=\"%s\">%n więcej</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s i %n więcej","%s i %n więcej","%s i %n więcej"),
"Hello %s," => "Witaj %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Otrzymujesz ten email, ponieważ w ostatniej godzinie zdarzyły się następujące rzeczy w %s",
"You are receiving this email because in the last day the following things happened at %s" => "Otrzymujesz ten email, ponieważ ostatniego dnia zdarzyły się następujące rzeczy w %s",
"You are receiving this email because in the last week the following things happened at %s" => "Otrzymujesz ten email, ponieważ w ostatnim tygodniu zdarzyły się następujące rzeczy w %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Zobaczysz listę wydarzeń tutaj, podczas rozpoczęcia korzystania z twojego %s",
"No more events to load" => "Nie pozostały już żadne zdarzenia do załadowania",
"Enable RSS feed" => "Włącz strumień RSS",
"Notifications" => "Powiadomienia",
"Mail" => "Poczta",
"Stream" => "Strumień",
"Notify about my own actions" => "Powiadamiaj mnie o moich aktywnościach",
"You need to set up your email address before you can receive notification emails." => "Musisz najpierw ustawić adres email zanim będziesz mógł otrzymywać powiadomienia.",
"Send emails:" => "Wyślij maile:",
"Hourly" => "Co godzinę",
"Daily" => "Codziennie",
"Weekly" => "Cotygodniowo",
"Activity feed" => "Strumień aktywności",
"Personal activity feed for %s" => "Osobisty strumień aktywności dla %s"
);
$PLURAL_FORMS = "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
